==> haskell-incremental-parser-0.5.1-126-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 incremental-parser
version:              0.5.1
visibility:           public
id:                   incremental-parser-0.5.1-Hycacgwo75v5IInrlSn6OO
key:                  incremental-parser-0.5.1-Hycacgwo75v5IInrlSn6OO
license:              GPL-3.0-only
copyright:            (c) 2011-2023 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://github.com/blamario/incremental-parser
synopsis:
    Generic parser library capable of providing partial results from partial input.

description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.

category:             Parsing
abi:                  59d46152f2917d66693dcb02f7baae8b
exposed:              True
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric

import-dirs:          /usr/lib/ghc-9.4.8/site-local/incremental-parser-0.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/incremental-parser-0.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/incremental-parser-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-incremental-parser
hs-libraries:         HSincremental-parser-0.5.1-Hycacgwo75v5IInrlSn6OO
depends:
    base-4.17.2.1 input-parsers-0.3.0.2-I3wZJQc9w9S5JwcgJH8vHA
    logict-0.8.1.0-KeH1RyziBZh4MjDjx1NGSk
    monoid-subclasses-1.2.6-Hxa1MeVoe0648jPsXa5axE
    parsers-0.12.12-FeDsK74ZKVnKzsYPDMhAKA
    rank2classes-1.5.4-LBNa0PZ6W9CAxawFk3rEZY transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock

haddock-html:         /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-incremental-parser-0.5.1-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 incremental-parser
version:              0.5.1
visibility:           public
id:                   incremental-parser-0.5.1-B8L3wokxE6gJHzvegVJXLb
key:                  incremental-parser-0.5.1-B8L3wokxE6gJHzvegVJXLb
license:              GPL-3.0-only
copyright:            (c) 2011-2023 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://github.com/blamario/incremental-parser
synopsis:
    Generic parser library capable of providing partial results from partial input.

description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.

category:             Parsing
abi:                  946478cee47787e84ee4ca6f8ce69ef2
exposed:              True
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric

import-dirs:          /usr/lib/ghc-9.4.8/site-local/incremental-parser-0.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/incremental-parser-0.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/incremental-parser-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-incremental-parser
hs-libraries:         HSincremental-parser-0.5.1-B8L3wokxE6gJHzvegVJXLb
depends:
    base-4.17.2.1 input-parsers-0.3.0.2-7yOlITpLpQ7fQTv1G6uv0
    logict-0.8.1.0-FOdRz8gwNjd8bneaHUC5Ar
    monoid-subclasses-1.2.6-1BcFsUegIP8CDeWSBrJXTu
    parsers-0.12.12-KoAUVrAe7crFLX2YZ2HXgQ
    rank2classes-1.5.4-FNtKPlgKrL25CocCA43DH2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock

haddock-html:         /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
